function [xvect,xdif,fx,nit]=adptnewt(x0,tol,nmax,fun,dfun)
%NEWTON Newton method
% [XVECT,XDIF,FX,NIT]=NEWTON(XM1,X0,TOL,NMAX,FUN,DFUN) tries to find a zero
% of the continuous function FUN using the Newton method starting from
% the initial guess X0. FUN and DFUN accept
% real scalar input x and returns a real scalar value. XVECT is the 
% vector of iterates, XDIF the vector of the differences between
% consecutive iterates, FX the residual. TOL specifies the tolerance of the
% method.
xvect=x0; 
nit=0; r=[1]; err=tol+1; m=[1]; xdif=[];
while nit<nmax & err>tol
    nit=nit+1; 
    x=xvect(nit); fx(nit)=eval(fun); f1x=eval(dfun);
    if f1x == 0
        fprintf(' Stop due to vanishing derivative  '); 
        return
    end;
    x=x-m(nit)*fx(nit)/f1x; 
    xvect=[xvect;x]; fx=[fx;eval(fun)];
    rd=err; err=abs(xvect(nit+1)-xvect(nit)); xdif=[xdif;err];
    ra=err/rd; r=[r;ra]; diff=abs(r(nit+1)-r(nit));
    if diff<1.e-3 & r(nit+1)>1.e-2 
        m(nit+1)=max(m(nit),1/abs(1-r(nit+1)));
    else
        m(nit+1)=m(nit); 
    end
end
return