function [x,k]=arnoldimet(A,b,x0,m,tol)
%ARNOLDIMET Arnoldi method 
%  [X,ITER]=ARNOLDIMET(A,B,X0,M,TOL) attempts to solve the system 
%  A*X=B with the Arnoldi method. TOL specifies the tolerance of the method. 
%  M specifies the maximum number of iterations. X0 specifies the initial 
%  guess. ITER is the iteration number at which X is computed.
r0=b-A*x0;  nr0=norm(r0,2);
if nr0 ~= 0
    v1=r0/nr0; V=[v1]; H=[]; k=0; istop=0;
    while k<= m-1 & istop == 0
        [k,V,H] = GSarnoldi(A,m,k,V,H);
        [nr,nc]=size(H); e1=eye(nc);
        y=(e1(:,1)'*nr0)/H(1:nc,:);
        residual = H(nr,nc)*abs(y*e1(:,nc));
        if residual <= tol
            istop = 1; y=y';
        end
    end
    if istop==0
        [nr,nc]=size(H);  e1=eye(nc);
        y=(e1(:,1)'*nr0)/H(1:nc,:); y=y';
    end
    x=x0+V(:,1:nc)*y;
else
   x=x0;
end
return