function [x,iter]=broyden(F,Q,x0,tol,nmax)
%BROYDEN Broyden method for nonlinear systems
%  [X, ITER] = BROYDEN(F, Q, X0, TOL, NMAX) attempts to solve the 
%  nonlinear system F(X)=0 with the Broyden method. F is a string variable 
%  containing the functional expressions of the nonlinear equations. Q is a 
%  starting approximation of the Jacobian. X0 specifies the initial guess. 
%  TOL specifies the tolerance of the method. NMAX specifies the maximum 
%  number of iterations. ITER is the iteration number at which X is computed.
[n,m]=size(F); 
if n ~= m, error('Only square systems'); end
iter=0; err=1+tol; fk=zeros(n,1); fk1=fk; x=x0;
for i=1:n
    fk(i)=eval(F(i,:)); end
    while iter < nmax & err > tol
        s=-Q \ fk;  
        x=s+x;
        err=norm(s,inf);
        if err > tol
            for i=1:n,  fk1(i)=eval(F(i,:));  end
            Q=Q+1/(s'*s)*fk1*s';
        end
        iter=iter+1; 
        fk=fk1;
    end
end
return
