function [A]=chol2(A)
% CHOL2 Cholesky factorization of a s.p.d. matrix A.
% R=CHOL2(A) produces an upper triangular matrix R such that
% R'*R=A.
[n,m]=size(A);
if n ~= m, error('Only squared systems'); end
for k=1:n-1
    if A(k,k) <= 0, error('Null or negative pivot element'); end
    A(k,k)=sqrt(A(k,k));   A(k+1:n,k)=A(k+1:n,k)/A(k,k);
    for j=k+1:n,   A(j:n,j)=A(j:n,j)-A(j:n,k)*A(j,k);   end
end
A(n,n)=sqrt(A(n,n));
A = tril(A); A=A';
return