function [k1]=condest2(A,L,U,theta)
%CONDEST2 Condition number
%  K1=CONDEST2(A,L,U,THETA) returns an approximation of the
%  condition number of a matrix A. L and U are the factor of
%  the LU factorization of A. THETA contains random numbers.
[n,m]=size(A);
if n ~= m, error('Only squared systems'); end
p = zeros(1,n);
for k=1:n
    zplus=(theta(k)-p(k))/U(k,k);   zminu=(-theta(k)-p(k))/U(k,k);
    splus=abs(theta(k)-p(k));       sminu=abs(-theta(k)-p(k));
    for i=k+1:n
        splus=splus+abs(p(i)+U(k,i)*zplus); 
        sminu=sminu+abs(p(i)+U(k,i)*zminu);  
    end   
    if splus >= sminu,  z(k)=zplus;   else,  z(k)=zminu;  end
    i=[k+1:n];  p(i)=p(i)+U(k,i)*z(k);
end
z = z'; 
x = backwardcol(L',z); 
w = forwardcol(L,x);   
y = backwardcol(U,w);
k1=norm(A,1)*norm(y,1)/norm(x,1);
return