function [D,sweep,psi]=cycjacobi(A,tol,nmax)
%CYCJACOBI Cyclic Jacobi method.
%  [D,SWEEP,PSI]=CYCJACOBI(A,TOL) computes the eigenvalues D of the symmetric
%  matrix A. TOL specifies the tolerance of the method. PSI=PSINORM(D) and
%  SWEEP is the number of sweeps.
[n,m]=size(A);
if n~=m, error('Only square matrices'); end
D=A; 
psi=norm(A,'fro');
epsi=tol*psi; 
psi=psinorm(D); 
sweep=0; 
iter=0;
while psi>epsi&iter<=nmax
    iter = iter + 1;
    sweep=sweep+1;
    for p=1:n-1 
        for q=p+1:n
            [c,s]=symschur(D,p,q); 
            [D]=gacol(D,c,s,1,n,p,q); 
            [D]=garow(D,c,s,p,q,1,n);
        end
    end
    psi=psinorm(D);
end
return