function [alpha,res,iter]=fixposys(F,Phi,x0,tol,nmax,dim)
%FIXPOSYS Fixed-point method for nonlinear systems
%  [ALPHA, RES, ITER] = FIXPOSYS(F, PHI, X0, TOL, NMAX, DIM) attempts
%  to solve the nonlinear system F(X)=0 with the Fixed Point method. 
%  F and PHI are string variables containing the functional expressions 
%  of the nonlinear equations and of the iteration function. 
%  X0 specifies the initial guess. TOL specifies the tolerance of the method. 
%  NMAX specifies the maximum number of iterations. 
%  DIM is the size of the nonlinear system. 
%  ITER is the iteration number at which ALPHA is computed. 
%  RES is the system residual computed at ALPHA.
x = x0; alpha=[x']; res = 0;
for k=1:dim
    r=abs(eval(F(k,:))); if (r > res), res = r; end
end;
iter = 0;
residual(1)=res;
while ((iter <= nmax) & (res >= tol)),
   iter = iter + 1;
   for k = 1:dim
       xnew(k) = eval(Phi(k,:));
   end
   x = xnew; res = 0; alpha=[alpha;x]; x=x';
   for k = 1:dim
       r = abs(eval(F(k,:)));
       if (r > res), res=r; end,
   end
   residual(iter+1)=res;
end
res=residual';
return

