function [x,vinc,iter]=lagrmult(f,h,x0,lambda0,tol,alpha0,beta)
%LAGRMULT Method of Lagrange multipliers for constrained function optimization
%  [X,VINC,ITER]=LAGRMULT(F,H,X0,LAMBDA0,TOL,ALPHA0,BETA) attempts 
%  to compute the minimizer X of a function F with the method of Lagrange
%  multipliers. F ia a string containing the functional expressions of the function. 
%  X0 and LAMBDA0 specify the initial guesses. H is a string variable containing the 
%  constraint. TOL specifies the tolerance of the method. ALPHA0 and BETA are given 
%  parameters. ITER is the iteration number at which X is computed. VINC is the 
%  accuracy at which the constraint is satisfied.
x = x0; [r,c]=size(h); vinc = 0; lambda = lambda0;
for i=1:r
    vinc = max(vinc,eval(h(i,1:c)));   
end
norm2h=['(',h(1,1:c),')^2'];
for i=2:r
    norm2h=[norm2h,'+(',h(i,1:c),')^2'];    
end
alpha = alpha0; 
options(1)=0; options(2)=tol*0.1; 
iter = 0;
while vinc > tol
    lh=['(',h(1,1:c),')*',num2str(lambda(1))];
    for i=2:r
        lh=[lh,'+(',h(i,1:c),')*',num2str(lambda(i))];
    end
    g=[f,'+0.5*',num2str(alpha,16),'*',norm2h,'+',lh];
    [x]=fmins(g,x,options);
    vinc=0; 
    iter = iter + 1;
    for i=1:r 
        vinc = max(vinc,eval(h(i,1:c)));  
    end
    alpha=alpha*beta;
    for i=1:r
        lambda(i)=lambda(i)+alpha*eval(h(i,1:c)); 
    end
end
return
