function [xk,relres,iter]=lanczosnosym(A,b,x0,m,tol)
%LANCZOSNOSYM Lanczos method
%  [X,RELRES,ITER]=LANCZOSNOSYM(A,B,X0,M,TOL) attempts to solve the system 
%  A*X=B with the Lanczos method. TOL specifies the tolerance of the method. 
%  M specifies the maximum number of iterations. X0 specifies the initial 
%  guess. ITER is the iteration number at which X is computed.
r0=b-A*x0; relres0=norm(r0,2); 
if relres0 ~= 0
    V=r0/relres0;  Z=V; gamma(1)=0; beta(1)=0;  k=1; relres=1;
    while k <= m & relres > tol
        vk=V(:,k);  zk=Z(:,k);
        if k==1
            vk1=0*vk;   zk1=0*zk;
        else
            vk1=V(:,k-1);  zk1=Z(:,k-1);  
        end
        alpha(k)=zk'*A*vk;
        tildev=A*vk-alpha(k)*vk-beta(k)*vk1;
        tildez=A'*zk-alpha(k)*zk-gamma(k)*zk1;
        gamma(k+1)=sqrt(abs(tildez'*tildev));
        if gamma(k+1) == 0    
            k=m+2;
        else
            beta(k+1)=tildez'*tildev/gamma(k+1);
            Z=[Z,tildez/beta(k+1)];      V=[V,tildev/gamma(k+1)];
        end
        if k~=m+2 
            if k==1
                Tk = alpha;
            else
                Tk=diag(alpha)+diag(beta(2:k),1)+diag(gamma(2:k),-1);
            end
            yk=Tk\(relres0*[1,0*[1:k-1]]');
            xk=x0+V(:,1:k)*yk;
            relres=abs(gamma(k+1)*[0*[1:k-1],1]*yk)*norm(V(:,k+1),2)/relres0;
            k=k+1;
        end
    end
else
    x=x0;
end
if k==m+2, iter=-k; else, iter=k-1; end
return