function int = newtcot(a,b,n,fun)
%NEWTCOT Newton-Cotes formulae.
% INT=NEWTCOT(A,B,N,FUN) computes an approximation of the integral of the 
% function FUN in (A,B) via a closed Newton-Cotes formula with N nodes. 
% FUN accepts a real vector input x and returns a real vector value.
h=(b-a)/n; 
n2=fix(n/2); 
if n > 6, error('Maximum value of n equal to 6'); end
a03=1/3; a08=1/8; a45=1/45; a288=1/288; a140=1/140;
alpha=[0.5     0        0        0; ...
       a03     4*a03    0        0; ...
       3*a08   9*a08    0        0; ...
       14*a45  64*a45   24*a45   0; ...
       95*a288 375*a288 250*a288 0; ...
       41*a140 216*a140 27*a140  272*a140];
x=a; y(1)=eval(fun); 
for j=2:n+1    
    x=x+h; y(j)=eval(fun); 
end
int=0; 
j=[1:n2+1];   int=sum(y(j).*alpha(n,j));
j=[n2+2:n+1]; int=int+sum(y(j).*alpha(n,n-j+2)); 
int=int*h;
return