function [x,iter]=newtonsys(F,J,x0,tol,nmax,p)
%NEWTONSYS NEWTON method for nonlinear systems
%  [X, ITER] = NEWTONSYS(F, J, X0, TOL, NMAX, P) attempts to solve the 
%  nonlinear system F(X)=0 with the Newton method. F and J are strings 
%  containing the functional expressions of the nonlinear equations and of
%  the Jacobian matrix. X0 specifies the initial guess. TOL specifies the
%  tolerance of the method. NMAX specifies the maximum number of iterations.
%  P specifies the number of consecutive steps during which the Jacobian is
%  mantained fixed. ITER is the iteration number at which X is computed.
[n,m]=size(F); 
if n ~= m, error('Only square systems'); end
iter=0; Fxn=zeros(n,1); x=x0; err=tol+1;
for i=1:n 
    for j=1:n 
        Jxn(i,j)=eval(J((i-1)*n+j,:)); 
    end
end
[L,U,P]=lu(Jxn); 
step=0;
while err>tol
    if step == p
        step = 0;
        for i=1:n
            Fxn(i)=eval(F(i,:));
            for j=1:n; Jxn(i,j)=eval(J((i-1)*n+j,:)); end
        end
        [L,U,P]=lu(Jxn);
    else
        for i=1:n, Fxn(i)=eval(F(i,:)); end
    end
    iter=iter+1; step=step+1; Fxn=-P*Fxn; 
    y=forwardcol(L,Fxn); 
    deltax=backwardcol(U,y); 
    x = x + deltax;  
	err=norm(deltax);
    if iter > nmax
        error(' Fails to converge within maximum number of iterations '); 
    end
end
return