function [lambda,x,iter,relres]=powerm(A,z0,tol,nmax)
%POWERM Power method
%  [LAMBDA,X,ITER,RELRES]=POWERM(A,Z0,TOL,NMAX) computes the
%  eigenvalue LAMBDA of the matrix A having largest module and the corresponding
%  unitary eigenvector X. TOL specifies the tolerance of the method. 
%  NMAX specifies the maximum number of iterations. Z0 specifies the initial 
%  guess. ITER is the iteration number at which X is computed.
q=z0/norm(z0); q2=q; 
relres=tol+1; iter=0; z=A*q;
while relres(end)>=tol & iter<=nmax
 q=z/norm(z); z=A*q; 
 lambda=q'*z; x=q;
 z2=q2'*A; q2=z2/norm(z2); q2=q2'; 
 y1=q2; costheta=abs(y1'*x);
 if costheta >= 5e-2
   iter=iter+1; 
   temp=norm(z-lambda*q)/costheta;
   relres=[relres; temp];
 else
   disp(' Multiple eigenvalue '); break;
 end
end
return
