function [t,u]=predcor(a,b,at,bt,h,f,t0,u0,tf,pece,m)
%PREDCOR Predictor-corrector method.
%   [T,U]=PREDCOR(A,B,AT,BT,TF,T0,U0,H,FUN,PECE,M) solves a 
%   Cauchy problem Y'=FUN(T,Y) for T in (T0,TF) using a predictor method
%   with coefficients AT and BT for the predictor, A and B for the corrector. 
%   H specifies the time-step. If PECE=1 P(EC)^mE method is selected, conversely 
%   the P(EC)^m is considered.
p  = max(length(a),length(b)-1); 
pt = max(length(at),length(bt)); 
q  = max(p,pt); if length(u0)<q, break, end; 
t  = [t0:h:t0+(q-1)*h]; u = u0; y = u0; fe = eval(f); 
k  = q; 
for t = t0+q*h:h:tf
    ut=sum(at.*u(k:-1:k-pt+1))+h*sum(bt.*fe(k:-1:k-pt+1));
    y=ut; foy=eval(f);
    uv=sum(a.*u(k:-1:k-p+1))+h*sum(b(2:p+1).*fe(k:-1:k-p+1));
    k = k+1;
    for j=1:m
        fy=foy; up=uv+h*b(1)*fy; y=up; foy=eval(f);
    end
    if pece=='y'|pece=='Y'
        fe=[fe,foy];
    else
        fe=[fe,fy];
    end
    u=[u,up];
end
t=[t0:h:tf];
return