function [T,iter]=qr2shift(A,tol,nmax)
%QR2SHIFT QR iteration with double shifting technique.
%  [T,ITER]=QR2SHIFT(A,TOL,NMAX) computes after ITER iterations the real 
%  Schur form T of the matrix A with a tolerance TOL. NMAX specifies 
%  the maximum number of iterations.
[n,m]=size(A);
if n~=m, error('Only square matrices'); end
iter=0; [T,Q]=houshess(A);
for k=n:-1:2
    I=eye(k); 
    while abs(T(k,k-1))>tol*(abs(T(k,k))+abs(T(k-1,k-1)))
        iter=iter+1;  
        if iter > nmax, return, end
        mu=T(k,k); [Q,R,c,s]=qrgivens(T(1:k,1:k)-mu*I);
        T(1:k,1:k)=R*Q+mu*I; 
        if k > 2 
            Tdiag2=abs(T(k-1,k-1))+abs(T(k-2,k-2));
            if abs(T(k-1,k-2))<=tol*Tdiag2;
                [lambda]=eig(T(k-1:k,k-1:k));
                [Q,R,c,s]=qrgivens(T(1:k,1:k)-lambda(1)*I);
                T(1:k,1:k)=R*Q+lambda(1)*I;
                [Q,R,c,s]=qrgivens(T(1:k,1:k)-lambda(2)*I);
                T(1:k,1:k)=R*Q+lambda(2)*I;
            end
        end
    end 
    T(k,k-1)=0;
end
I=eye(2);
while (abs(T(2,1))>tol*(abs(T(2,2))+abs(T(1,1)))) & (iter<=nmax)
    iter=iter+1; 
    mu=T(2,2);
    [Q,R,c,s]=qrgivens(T(1:2,1:2)-mu*I);  
    T(1:2,1:2)=R*Q+mu*I;
end
return