function [T,iter]=qrshift(A,tol,nmax)
%QRSHIFT QR iteration with single shifting technique.
%  [T,ITER]=QRSHIFT(A,TOL,NMAX) computes after ITER iterations the real 
%  Schur form T of the matrix A with a tolerance TOL. NMAX specifies 
%  the maximum number of iterations.
[n,m]=size(A);
if n~=m, error('Only square matrices'); end
iter=0; [T,Q]=houshess(A);
for k=n:-1:2
    I=eye(k); 
    while abs(T(k,k-1))>tol*(abs(T(k,k))+abs(T(k-1,k-1)))
        iter=iter+1;
        if iter > nmax 
            return
        end
        mu=T(k,k); [Q,R,c,s]=qrgivens(T(1:k,1:k)-mu*I);
        T(1:k,1:k)=R*Q+mu*I;
    end
    T(k,k-1)=0; 
end
return